@@ -2,9 +2,11 @@ import { useEffect, useState } from 'react';
 import { useAsyncFn } from 'react-use';
 
 import { SelectableValue } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { getBackendSrv } from '@grafana/runtime';
 import { AsyncSelect } from '@grafana/ui';
-import { Organization, UserOrg } from 'app/types';
+import { Organization } from 'app/types/organization';
+import { UserOrg } from 'app/types/user';
 
 export type OrgSelectItem = SelectableValue<Organization>;
 
@@ -65,8 +67,8 @@ export function OrgPicker({ onSelected, className, inputId, autoFocus, excludeOr
         setSelected(item);
       }}
       value={selected}
-      placeholder="Select organization"
-      noOptionsMessage="No organizations found"
+      placeholder={t('org-picker.select-placeholder', 'Select organization')}
+      noOptionsMessage={t('org-picker.noOptionsMessage-no-organizations-found', 'No organizations found')}
     />
   );
 }
