@@ -1,7 +1,6 @@
 import { useMemo } from 'react';
 
 import { EditableDashboardElement } from '../scene/types/EditableDashboardElement';
-import { MultiSelectedEditableDashboardElement } from '../scene/types/MultiSelectedEditableDashboardElement';
 import { getDashboardSceneFor } from '../utils/utils';
 
 import { DashboardEditPane } from './DashboardEditPane';
@@ -10,7 +9,7 @@ import { ElementSelection } from './ElementSelection';
 export function useEditableElement(
   selection: ElementSelection | undefined,
   editPane: DashboardEditPane
-): EditableDashboardElement | MultiSelectedEditableDashboardElement | undefined {
+): EditableDashboardElement | undefined {
   return useMemo(() => {
     if (!selection) {
       const dashboard = getDashboardSceneFor(editPane);
