@@ -1,15 +1,12 @@
 import { css } from '@emotion/css';
-import { PureComponent } from 'react';
+import { memo } from 'react';
 
 import { QueryEditorHelpProps } from '@grafana/data';
 
 import { CloudMonitoringQuery } from '../types/query';
 
-export default class CloudMonitoringCheatSheet extends PureComponent<
-  QueryEditorHelpProps<CloudMonitoringQuery>,
-  { userExamples: string[] }
-> {
-  render() {
+const CloudMonitoringCheatSheet = memo(
+  ({ query, datasource, onClickExample }: QueryEditorHelpProps<CloudMonitoringQuery>) => {
     return (
       <div>
         <h2>Cloud Monitoring alias patterns</h2>
@@ -75,4 +72,8 @@ export default class CloudMonitoringCheatSheet extends PureComponent<
       </div>
     );
   }
-}
+);
+
+CloudMonitoringCheatSheet.displayName = 'CloudMonitoringCheatSheet';
+
+export default CloudMonitoringCheatSheet;
