@@ -1,4 +1,4 @@
-import { cloneDeep, first as _first, isNumber, isString, map as _map, find, isObject } from 'lodash';
+import { cloneDeep, first as _first, isNumber, isString, map as _map, isObject } from 'lodash';
 import { from, generate, lastValueFrom, Observable, of } from 'rxjs';
 import { catchError, first, map, mergeMap, skipWhile, throwIfEmpty, tap } from 'rxjs/operators';
 import { SemVer } from 'semver';
@@ -60,6 +60,7 @@ import {
   isPipelineAggregationWithMultipleBucketPaths,
 } from './components/QueryEditor/MetricAggregationsEditor/aggregations';
 import { metricAggregationConfig } from './components/QueryEditor/MetricAggregationsEditor/utils';
+import { ElasticsearchDataQuery, BucketAggregation } from './dataquery.gen';
 import { isMetricAggregationWithMeta } from './guards';
 import {
   addAddHocFilter,
@@ -71,10 +72,8 @@ import {
 import { trackAnnotationQuery, trackQuery } from './tracking';
 import {
   Logs,
-  BucketAggregation,
   DataLinkConfig,
   ElasticsearchOptions,
-  ElasticsearchQuery,
   TermsQuery,
   Interval,
   ElasticsearchAnnotationQuery,
@@ -83,7 +82,7 @@ import {
   isElasticsearchResponseWithHits,
   ElasticsearchHits,
 } from './types';
-import { getScriptValue, isSupportedVersion, isTimeSeriesQuery, unsupportedVersionMessage } from './utils';
+import { getScriptValue, isTimeSeriesQuery } from './utils';
 
 export const REF_ID_STARTER_LOG_VOLUME = 'log-volume-';
 export const REF_ID_STARTER_LOG_SAMPLE = 'log-sample-';
@@ -103,13 +102,13 @@ const ELASTIC_META_FIELDS = [
 ];
 
 export class ElasticDatasource
-  extends DataSourceWithBackend<ElasticsearchQuery, ElasticsearchOptions>
+  extends DataSourceWithBackend<ElasticsearchDataQuery, ElasticsearchOptions>
   implements
     DataSourceWithLogsContextSupport,
-    DataSourceWithQueryImportSupport<ElasticsearchQuery>,
-    DataSourceWithSupplementaryQueriesSupport<ElasticsearchQuery>,
-    DataSourceWithToggleableQueryFiltersSupport<ElasticsearchQuery>,
-    DataSourceWithQueryModificationSupport<ElasticsearchQuery>
+    DataSourceWithQueryImportSupport<ElasticsearchDataQuery>,
+    DataSourceWithSupplementaryQueriesSupport<ElasticsearchDataQuery>,
+    DataSourceWithToggleableQueryFiltersSupport<ElasticsearchDataQuery>,
+    DataSourceWithQueryModificationSupport<ElasticsearchDataQuery>
 {
   basicAuth?: string;
   withCredentials?: boolean;
@@ -182,7 +181,7 @@ export class ElasticDatasource
    * Imports queries from AbstractQuery objects when switching between different data source types.
    * @returns A Promise that resolves to an array of ES queries.
    */
-  async importFromAbstractQueries(abstractQueries: AbstractQuery[]): Promise<ElasticsearchQuery[]> {
+  async importFromAbstractQueries(abstractQueries: AbstractQuery[]): Promise<ElasticsearchDataQuery[]> {
     return abstractQueries.map((abstractQuery) => this.languageProvider.importFromAbstractQuery(abstractQuery));
   }
 
@@ -292,8 +291,8 @@ export class ElasticDatasource
     const dateRanges = [];
     const rangeStart: RangeMap = {};
     rangeStart[timeField] = {
-      from: options.range.from.valueOf(),
-      to: options.range.to.valueOf(),
+      gte: options.range.from.valueOf(),
+      lte: options.range.to.valueOf(),
       format: 'epoch_millis',
     };
     dateRanges.push({ range: rangeStart });
@@ -301,8 +300,8 @@ export class ElasticDatasource
     if (timeEndField) {
       const rangeEnd: RangeMap = {};
       rangeEnd[timeEndField] = {
-        from: options.range.from.valueOf(),
-        to: options.range.to.valueOf(),
+        gte: options.range.from.valueOf(),
+        lte: options.range.to.valueOf(),
         format: 'epoch_millis',
       };
       dateRanges.push({ range: rangeEnd });
@@ -434,44 +433,13 @@ export class ElasticDatasource
    * @returns An array of ES queries with interpolated variables and ad hoc filters using `applyTemplateVariables`.
    */
   interpolateVariablesInQueries(
-    queries: ElasticsearchQuery[],
+    queries: ElasticsearchDataQuery[],
     scopedVars: ScopedVars,
     filters?: AdHocVariableFilter[]
-  ): ElasticsearchQuery[] {
+  ): ElasticsearchDataQuery[] {
     return queries.map((q) => this.applyTemplateVariables(q, scopedVars, filters));
   }
 
-  /**
-   * @todo Remove as we have health checks in the backend
-   */
-  async testDatasource() {
-    // we explicitly ask for uncached, "fresh" data here
-    const dbVersion = await this.getDatabaseVersion(false);
-    // if we are not able to determine the elastic-version, we assume it is a good version.
-    const isSupported = dbVersion != null ? isSupportedVersion(dbVersion) : true;
-    const versionMessage = isSupported ? '' : `WARNING: ${unsupportedVersionMessage} `;
-    // validate that the index exist and has date field
-    return lastValueFrom(
-      this.getFields(['date']).pipe(
-        mergeMap((dateFields) => {
-          const timeField = find(dateFields, { text: this.timeField });
-          if (!timeField) {
-            return of({
-              status: 'error',
-              message: 'No date field named ' + this.timeField + ' found',
-            });
-          }
-          return of({ status: 'success', message: `${versionMessage}Data source successfully connected.` });
-        }),
-        catchError((err) => {
-          const infoInParentheses = err.message ? ` (${err.message})` : '';
-          const message = `Unable to connect with Elasticsearch${infoInParentheses}. Please check the server logs for more details.`;
-          return of({ status: 'error', message });
-        })
-      )
-    );
-  }
-
   // Private method used in `getTerms` to get the header for the Elasticsearch query
   private getQueryHeader(searchType: string, timeFrom?: DateTime, timeTo?: DateTime): string {
     const queryHeader = {
@@ -488,7 +456,7 @@ export class ElasticDatasource
    * Used, for example, in Query history.
    * @returns A text representation of the query.
    */
-  getQueryDisplayText(query: ElasticsearchQuery) {
+  getQueryDisplayText(query: ElasticsearchDataQuery) {
     // TODO: This might be refactored a bit.
     const metricAggs = query.metrics;
     const bucketAggs = query.bucketAggs;
@@ -566,8 +534,8 @@ export class ElasticDatasource
    */
   getSupplementaryRequest(
     type: SupplementaryQueryType,
-    request: DataQueryRequest<ElasticsearchQuery>
-  ): DataQueryRequest<ElasticsearchQuery> | undefined {
+    request: DataQueryRequest<ElasticsearchDataQuery>
+  ): DataQueryRequest<ElasticsearchDataQuery> | undefined {
     switch (type) {
       case SupplementaryQueryType.LogsVolume:
         return this.getLogsVolumeDataProvider(request);
@@ -592,9 +560,16 @@ export class ElasticDatasource
    * It retrieves supplementary queries based on the provided options and ES query.
    * @returns A supplemented ES query or undefined if unsupported.
    */
-  getSupplementaryQuery(options: SupplementaryQueryOptions, query: ElasticsearchQuery): ElasticsearchQuery | undefined {
+  getSupplementaryQuery(
+    options: SupplementaryQueryOptions,
+    query: ElasticsearchDataQuery
+  ): ElasticsearchDataQuery | undefined {
     let isQuerySuitable = false;
 
+    if (query.hide) {
+      return undefined;
+    }
+
     switch (options.type) {
       case SupplementaryQueryType.LogsVolume:
         // it has to be a logs-producing range-query
@@ -669,12 +644,12 @@ export class ElasticDatasource
    * @returns An Observable of DataQueryResponse or undefined if no suitable queries are found.
    */
   private getLogsVolumeDataProvider(
-    request: DataQueryRequest<ElasticsearchQuery>
-  ): DataQueryRequest<ElasticsearchQuery> | undefined {
+    request: DataQueryRequest<ElasticsearchDataQuery>
+  ): DataQueryRequest<ElasticsearchDataQuery> | undefined {
     const logsVolumeRequest = cloneDeep(request);
     const targets = logsVolumeRequest.targets
       .map((target) => this.getSupplementaryQuery({ type: SupplementaryQueryType.LogsVolume }, target))
-      .filter((query): query is ElasticsearchQuery => !!query);
+      .filter((query): query is ElasticsearchDataQuery => !!query);
 
     if (!targets.length) {
       return undefined;
@@ -688,14 +663,14 @@ export class ElasticDatasource
    * @returns An Observable of DataQueryResponse or undefined if no suitable queries are found.
    */
   private getLogsSampleDataProvider(
-    request: DataQueryRequest<ElasticsearchQuery>
-  ): DataQueryRequest<ElasticsearchQuery> | undefined {
+    request: DataQueryRequest<ElasticsearchDataQuery>
+  ): DataQueryRequest<ElasticsearchDataQuery> | undefined {
     const logsSampleRequest = cloneDeep(request);
     const targets = logsSampleRequest.targets;
     const queries = targets.map((query) => {
       return this.getSupplementaryQuery({ type: SupplementaryQueryType.LogsSample, limit: 100 }, query);
     });
-    const elasticQueries = queries.filter((query): query is ElasticsearchQuery => !!query);
+    const elasticQueries = queries.filter((query): query is ElasticsearchDataQuery => !!query);
 
     if (!elasticQueries.length) {
       return undefined;
@@ -707,7 +682,7 @@ export class ElasticDatasource
    * Required by DataSourceApi. It executes queries based on the provided DataQueryRequest.
    * @returns An Observable of DataQueryResponse containing the query results.
    */
-  query(request: DataQueryRequest<ElasticsearchQuery>): Observable<DataQueryResponse> {
+  query(request: DataQueryRequest<ElasticsearchDataQuery>): Observable<DataQueryResponse> {
     const start = new Date();
     return super.query(request).pipe(
       tap((response) => trackQuery(response, request, start)),
@@ -725,7 +700,7 @@ export class ElasticDatasource
    * It is called from DatasourceWithBackend.
    * @returns `true` if the query is not hidden.
    */
-  filterQuery(query: ElasticsearchQuery): boolean {
+  filterQuery(query: ElasticsearchDataQuery): boolean {
     if (query.hide) {
       return false;
     }
@@ -893,7 +868,11 @@ export class ElasticDatasource
    * Get values for a given field.
    * Used for example in getTagValues.
    */
-  getTerms(queryDef: TermsQuery, range = getDefaultTimeRange()): Observable<MetricFindValue[]> {
+  getTerms(
+    queryDef: TermsQuery,
+    range = getDefaultTimeRange(),
+    isTagValueQuery = false
+  ): Observable<MetricFindValue[]> {
     const searchType = 'query_then_fetch';
     const header = this.getQueryHeader(searchType, range.from, range.to);
     let esQuery = JSON.stringify(this.queryBuilder.getTermsQuery(queryDef));
@@ -915,9 +894,10 @@ export class ElasticDatasource
 
         const buckets = res.responses[0].aggregations['1'].buckets;
         return _map(buckets, (bucket) => {
+          const keyString = String(bucket.key);
           return {
-            text: bucket.key_as_string || bucket.key,
-            value: bucket.key,
+            text: bucket.key_as_string || keyString,
+            value: isTagValueQuery ? keyString : bucket.key,
           };
         });
       })
@@ -974,15 +954,15 @@ export class ElasticDatasource
    * Implemented as part of the DataSourceAPI. Retrieves tag values that can be used for ad-hoc filtering.
    * @returns A Promise that resolves to an array of label values represented as MetricFindValue objects
    */
-  getTagValues(options: DataSourceGetTagValuesOptions<ElasticsearchQuery>) {
-    return lastValueFrom(this.getTerms({ field: options.key }, options.timeRange));
+  getTagValues(options: DataSourceGetTagValuesOptions<ElasticsearchDataQuery>) {
+    return lastValueFrom(this.getTerms({ field: options.key }, options.timeRange, true));
   }
 
   /**
    * Implemented as part of the DataSourceAPI.
    * Used by alerting to check if query contains template variables.
    */
-  targetContainsTemplate(target: ElasticsearchQuery) {
+  targetContainsTemplate(target: ElasticsearchDataQuery) {
     if (this.templateSrv.containsTemplate(target.query) || this.templateSrv.containsTemplate(target.alias)) {
       return true;
     }
@@ -1047,7 +1027,7 @@ export class ElasticDatasource
    * It is used for example in Explore to toggle fields on and off trough log details.
    * @returns A new ES query with the filter toggled as specified.
    */
-  toggleQueryFilter(query: ElasticsearchQuery, filter: ToggleFilterAction): ElasticsearchQuery {
+  toggleQueryFilter(query: ElasticsearchDataQuery, filter: ToggleFilterAction): ElasticsearchDataQuery {
     let expression = query.query ?? '';
     switch (filter.type) {
       case 'FILTER_FOR': {
@@ -1074,7 +1054,7 @@ export class ElasticDatasource
    * Implemented for `DataSourceWithToggleableQueryFiltersSupport`. Checks if a query expression contains a filter based on the provided filter options.
    * @returns A boolean value indicating whether the filter exists in the query expression.
    */
-  queryHasFilter(query: ElasticsearchQuery, options: QueryFilterOptions): boolean {
+  queryHasFilter(query: ElasticsearchDataQuery, options: QueryFilterOptions): boolean {
     let expression = query.query ?? '';
     return queryHasFilter(expression, options.key, options.value);
   }
@@ -1084,7 +1064,7 @@ export class ElasticDatasource
    * It is used, for example, in the Query Builder to apply hints such as parsers, operations, etc.
    * @returns A new ES query with the specified modification applied.
    */
-  modifyQuery(query: ElasticsearchQuery, action: QueryFixAction): ElasticsearchQuery {
+  modifyQuery(query: ElasticsearchDataQuery, action: QueryFixAction): ElasticsearchDataQuery {
     if (!action.options) {
       return query;
     }
@@ -1130,7 +1110,7 @@ export class ElasticDatasource
     }
     let finalQuery = query;
     adhocFilters.forEach((filter) => {
-      finalQuery = addAddHocFilter(finalQuery, filter);
+      finalQuery = addAddHocFilter(finalQuery, filter, this.logLevelField);
     });
 
     return finalQuery;
@@ -1142,10 +1122,10 @@ export class ElasticDatasource
    * @returns A modified ES query with template variables and ad hoc filters applied.
    */
   applyTemplateVariables(
-    query: ElasticsearchQuery,
+    query: ElasticsearchDataQuery,
     scopedVars: ScopedVars,
     filters?: AdHocVariableFilter[]
-  ): ElasticsearchQuery {
+  ): ElasticsearchDataQuery {
     // We need a separate interpolation format for lucene queries, therefore we first interpolate any
     // lucene query string and then everything else
     const interpolateBucketAgg = (bucketAgg: BucketAggregation): BucketAggregation => {
@@ -1233,7 +1213,7 @@ export class ElasticDatasource
       },
     };
 
-    const query: ElasticsearchQuery = {
+    const query: ElasticsearchDataQuery = {
       refId: `log-context-${row.dataFrame.refId}-${direction}`,
       metrics: [logQuery],
       query: '',
@@ -1248,7 +1228,7 @@ export class ElasticDatasource
 
     const interval = rangeUtil.calculateInterval(range, 1);
 
-    const contextRequest: DataQueryRequest<ElasticsearchQuery> = {
+    const contextRequest: DataQueryRequest<ElasticsearchDataQuery> = {
       requestId: `log-context-request-${row.dataFrame.refId}-${options?.direction}`,
       targets: [query],
       interval: interval.interval,
